@@ -97,7 +97,8 @@ class CompareObject(object):
     def get_related(self):
         if self.field.rel is not None:
             obj = self.version.object_version.object
-            related = getattr(obj, self.field.name)
+            field_name = self.field.name
+            related = getattr(obj, field_name)
             return related
 
     def get_many_to_many(self):
